#
# spec file for package python-pytest-profiling
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pytest-profiling
Version:        1.8.1
Release:        1.1
Summary:        Profiling plugin for pytest
License:        MIT
URL:            https://github.com/man-group/pytest-plugins
Source:         https://files.pythonhosted.org/packages/source/p/pytest-profiling/pytest-profiling-%{version}.tar.gz
# https://github.com/man-group/pytest-plugins/issues/209
Patch0:         python-pytest-profiling-no-six.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools-git}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-gprof2dot
Requires:       python-pytest
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module gprof2dot}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pytest-virtualenv}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Profiling plugin for pytest

%prep
%autosetup -p1 -n pytest-profiling-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# integration tests omit as they try to use the system image instead of buildroot
%pytest -k 'not test_profile_integration'

%files %{python_files}
%doc CHANGES.md README.md
%license LICENSE
%{python_sitelib}/pytest_profiling.py
%pycache_only %{python_sitelib}/__pycache__/pytest_profiling*.pyc
%{python_sitelib}/pytest_profiling-%{version}.dist-info

%changelog
* Tue Feb  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.1:
  * Small refactor to make error messages a bit clearer
  * Fixed tests which were installing from PyPI rather than local
  * Removed usage of deprecated pytest.yield_fixture.
  * Removed usage of distutils, where possible.
- Refreshed python-pytest-profiling-no-six.patch
- Drop patch fix-type-arguments.patch, now included.
* Tue Oct 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.0:
  * Drop support for Python 2 and <3.6, removing compatibility code.
  * Use stdlib unittest.mock instead of mock package.
  * Removed usage of path.py and path in favour of pathlib.
  * Added support to hide/show the full path of file.
  * Remove pinning of more-itertools.
  * Add support to define element number for print_stats()
  * Fix mock in test_writes_summary
- Dropped patches, included upstream:
  * pytest-fixtures-pr171-remove-mock.patch
  * fix-mock-call.patch
- Add patch fix-type-arguments.patch:
  * Use correct type argument for argparse.
- Refreshed python-pytest-profiling-no-six.patch
* Tue Mar 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Less globs in %%files.
- Clean up Python 2 leftovers.
- Edit python-pytest-profiling-no-six.patch to also drop the
  install_requires.
- Add patch fix-mock-call.patch:
  * Correct mocking call to be assert_called_with().
* Thu Dec  8 2022 pgajdos@suse.com
- do not require mock
- use -p1 as quilt refresh does not like higher ones
- modified patches
  %% pytest-fixtures-pr171-remove-mock.patch (refreshed)
- added patches
  fix https://github.com/man-group/pytest-plugins/issues/209
  + python-pytest-profiling-no-six.patch
* Thu Apr 21 2022 Ben Greiner <code@bnavigator.de>
- Fix fallout from SUSE's crusade against mock because mock was
  required and is not pulled in anymore by something else
  * Add pytest-fixtures-pr171-remove-mock.patch
  * gh#man-group/pytest-plugins#171
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Support for pytest 4
* Thu Mar 21 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.6.0
